package de.intevation.gnv.math;

import de.intevation.gnv.jfreechart.PolygonDataset;

import java.io.Serializable;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 *  @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 *  @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public class AttributedXYColumns
implements   Serializable
{
    protected List<? extends XYColumn> columns;
    protected Map                      attributes;
    protected Interpolation3D          interpolation;
    protected PolygonDataset           dataset;

    public AttributedXYColumns() {
    }

    public AttributedXYColumns(List<? extends XYColumn> columns) {
        this(columns, null);
    }

    public AttributedXYColumns(
        List<? extends XYColumn> columns,
        Map attributes
    ) {
        this.columns    = columns;
        this.attributes = attributes;
    }

    public Object getAttribute(Object key) {
        return attributes != null
            ? attributes.get(key)
            : null;
    }

    public void setAttribute(Object key, Object value) {
        if (attributes == null) {
            attributes = new HashMap();
        }
        attributes.put(key, value);
    }

    public List<? extends XYColumn> getXYColumns() {
        return columns;
    }

    public void setXYColumns(List<? extends XYColumn> columns) {
        this.columns = columns;
    }

    public void setInterpolation(Interpolation3D interpolation) {
        this.interpolation = interpolation;
    }

    public Interpolation3D getInterpolation() {
        return interpolation;
    }

    public void setPolygonDataset(PolygonDataset dataset) {
        this.dataset = dataset;
    }

    public PolygonDataset getPolygonDataset() {
        return dataset;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
